==> bacula-docs-1.38.5.tar.gz: bacula-docs-1.38.5/manual/bacula/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/includegraphics{.slashwin32-start.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="293" HEIGHT="125" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="\includegraphics{./win32-start.eps}">|; 

$key = q/includegraphics{.slashbacula-objects.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="575" HEIGHT="732" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\includegraphics{./bacula-objects.eps}">|; 

$key = q/includegraphics{.slashaccess-is-denied.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="187" HEIGHT="125" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="\includegraphics{./access-is-denied.eps}">|; 

$key = q/includegraphics{.slashproperties-security.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="366" HEIGHT="441" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="\includegraphics{./properties-security.eps}">|; 

$key = q/includegraphics{.slasherror.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\includegraphics{./error.eps}">|; 

$key = q/includegraphics{.slashwin32-service-ok.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="361" HEIGHT="133" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\includegraphics{./win32-service-ok.eps}">|; 

$key = q/includegraphics{.slashconfirm.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="666" HEIGHT="139" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img27.png"
 ALT="\includegraphics{./confirm.eps}">|; 

$key = q/includegraphics{.slashrunning.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="\includegraphics{./running.eps}">|; 

$key = q/includegraphics{.slashwin32-finish.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="\includegraphics{./win32-finish.eps}">|; 

$key = q/includegraphics{.slashflow.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="478" HEIGHT="369" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\includegraphics{./flow.eps}">|; 

$key = q/includegraphics{.slashidle.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="\includegraphics{./idle.eps}">|; 

$key = q/includegraphics{.slashmenu.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="152" HEIGHT="115" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="\includegraphics{./menu.eps}">|; 

$key = q/includegraphics{.slashbacula-applications.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="574" HEIGHT="732" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="\includegraphics{./bacula-applications.eps}">|; 

$key = q/includegraphics{.slashwin32-pkg.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="502" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\includegraphics{./win32-pkg.eps}">|; 

$key = q/includegraphics{.slashview-only.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="424" HEIGHT="118" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="\includegraphics{./view-only.eps}">|; 

$key = q/includegraphics{.slashbimagemgr1.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="797" HEIGHT="598" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\includegraphics{./bimagemgr1.eps}">|; 

$key = q/includegraphics{.slashwin32-nsis.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="50" HEIGHT="48" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="\includegraphics{./win32-nsis.eps}">|; 

$key = q/includegraphics{.slashbimagemgr2.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="797" HEIGHT="598" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\includegraphics{./bimagemgr2.eps}">|; 

$key = q/includegraphics{.slashwin32-service.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="496" HEIGHT="125" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="\includegraphics{./win32-service.eps}">|; 

$key = q/includegraphics{.slashwin32-location.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="\includegraphics{./win32-location.eps}">|; 

$key = q/includegraphics{.slashwin32-welcome.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\includegraphics{./win32-welcome.eps}">|; 

$key = q/includegraphics{.slashbimagemgr3.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="797" HEIGHT="598" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\includegraphics{./bimagemgr3.eps}">|; 

$key = q/includegraphics{.slashtray-icon.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="85" HEIGHT="28" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="\includegraphics{./tray-icon.eps}">|; 

$key = q/includegraphics{.slashBacula-tray-monitor.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="835" HEIGHT="683" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="\includegraphics{./Bacula-tray-monitor.eps}">|; 

$key = q/includegraphics{.slashproperties-security-advanced-owner.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="484" HEIGHT="441" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="\includegraphics{./properties-security-advanced-owner.eps}">|; 

$key = q/includegraphics{.slashConf-Diagram.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="428" HEIGHT="510" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\includegraphics{./Conf-Diagram.eps}">|; 

$key = q/includegraphics{.slashbacula-logo.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="459" HEIGHT="99" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics{./bacula-logo.eps}">|; 

1;

==> bacula-docs-2.0.1.tar.gz: bacula-docs-2.0.1/manual/bacula/images.pl <==
# LaTeX2HTML 2002-2-1 (1.70)
# Associate images original text with physical files.


$key = q/includegraphics{.slashbacula-objects.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="573" HEIGHT="730" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img3.png"
 ALT="\includegraphics{./bacula-objects.eps}">|; 

$key = q/includegraphics{.slashaccess-is-denied.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="186" HEIGHT="125" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img22.png"
 ALT="\includegraphics{./access-is-denied.eps}">|; 

$key = q/includegraphics{.slashproperties-security.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="365" HEIGHT="439" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img24.png"
 ALT="\includegraphics{./properties-security.eps}">|; 

$key = q/includegraphics{.slasherror.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img21.png"
 ALT="\includegraphics{./error.eps}">|; 

$key = q/includegraphics{.slashwin32-installation-type.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="502" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img12.png"
 ALT="\includegraphics{./win32-installation-type.eps}">|; 

$key = q/includegraphics{.slashconfirm.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="664" HEIGHT="139" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img26.png"
 ALT="\includegraphics{./confirm.eps}">|; 

$key = q/includegraphics{.slashrunning.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img20.png"
 ALT="\includegraphics{./running.eps}">|; 

$key = q/includegraphics{.slashwin32-config.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="502" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img14.png"
 ALT="\includegraphics{./win32-config.eps}">|; 

$key = q/includegraphics{.slashwin32-installing.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img15.png"
 ALT="\includegraphics{./win32-installing.eps}">|; 

$key = q/includegraphics{.slashwin32-finish.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="502" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img16.png"
 ALT="\includegraphics{./win32-finish.eps}">|; 

$key = q/includegraphics{.slashflow.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="476" HEIGHT="368" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img4.png"
 ALT="\includegraphics{./flow.eps}">|; 

$key = q/includegraphics{.slashidle.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="32" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img17.png"
 ALT="\includegraphics{./idle.eps}">|; 

$key = q/includegraphics{.slashmenu.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="151" HEIGHT="115" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img19.png"
 ALT="\includegraphics{./menu.eps}">|; 

$key = q/includegraphics{.slashbacula-applications.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="572" HEIGHT="730" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img2.png"
 ALT="\includegraphics{./bacula-applications.eps}">|; 

$key = q/includegraphics{.slashwin32-pkg.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img13.png"
 ALT="\includegraphics{./win32-pkg.eps}">|; 

$key = q/includegraphics{.slashview-only.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="423" HEIGHT="118" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img23.png"
 ALT="\includegraphics{./view-only.eps}">|; 

$key = q/includegraphics{.slashbimagemgr1.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="794" HEIGHT="596" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img7.png"
 ALT="\includegraphics{./bimagemgr1.eps}">|; 

$key = q/includegraphics{.slashwin32-nsis.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="50" HEIGHT="48" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img10.png"
 ALT="\includegraphics{./win32-nsis.eps}">|; 

$key = q/includegraphics{.slashbimagemgr2.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="794" HEIGHT="596" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img8.png"
 ALT="\includegraphics{./bimagemgr2.eps}">|; 

$key = q/includegraphics{.slashwin32-welcome.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="501" HEIGHT="391" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img11.png"
 ALT="\includegraphics{./win32-welcome.eps}">|; 

$key = q/includegraphics{.slashbimagemgr3.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="794" HEIGHT="596" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img9.png"
 ALT="\includegraphics{./bimagemgr3.eps}">|; 

$key = q/includegraphics{.slashtray-icon.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="84" HEIGHT="28" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img18.png"
 ALT="\includegraphics{./tray-icon.eps}">|; 

$key = q/includegraphics{.slashBacula-tray-monitor.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="832" HEIGHT="681" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img5.png"
 ALT="\includegraphics{./Bacula-tray-monitor.eps}">|; 

$key = q/includegraphics{.slashproperties-security-advanced-owner.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="483" HEIGHT="439" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img25.png"
 ALT="\includegraphics{./properties-security-advanced-owner.eps}">|; 

$key = q/includegraphics{.slashConf-Diagram.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="426" HEIGHT="508" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img6.png"
 ALT="\includegraphics{./Conf-Diagram.eps}">|; 

$key = q/includegraphics{.slashbacula-logo.eps};LFS=11;AAT;NTR/;
$cached_env_img{$key} = q|<IMG
 WIDTH="457" HEIGHT="99" ALIGN="BOTTOM" BORDER="0"
 SRC="|."$dir".q|img1.png"
 ALT="\includegraphics{./bacula-logo.eps}">|; 

1;
